# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtSerialPort, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtSerialPort`

import PySide6.QtSerialPort
import PySide6.QtCore

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QSerialPort(PySide6.QtCore.QIODevice):

    baudRateChanged          : typing.ClassVar[Signal] = ... # baudRateChanged(int,QSerialPort::Directions)
    breakEnabledChanged      : typing.ClassVar[Signal] = ... # breakEnabledChanged(bool)
    dataBitsChanged          : typing.ClassVar[Signal] = ... # dataBitsChanged(QSerialPort::DataBits)
    dataTerminalReadyChanged : typing.ClassVar[Signal] = ... # dataTerminalReadyChanged(bool)
    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QSerialPort::SerialPortError)
    flowControlChanged       : typing.ClassVar[Signal] = ... # flowControlChanged(QSerialPort::FlowControl)
    parityChanged            : typing.ClassVar[Signal] = ... # parityChanged(QSerialPort::Parity)
    requestToSendChanged     : typing.ClassVar[Signal] = ... # requestToSendChanged(bool)
    settingsRestoredOnCloseChanged: typing.ClassVar[Signal] = ... # settingsRestoredOnCloseChanged(bool)
    stopBitsChanged          : typing.ClassVar[Signal] = ... # stopBitsChanged(QSerialPort::StopBits)

    class BaudRate(enum.IntEnum):

        Baud1200                  = 0x4b0
        Baud2400                  = 0x960
        Baud4800                  = 0x12c0
        Baud9600                  = 0x2580
        Baud19200                 = 0x4b00
        Baud38400                 = 0x9600
        Baud57600                 = 0xe100
        Baud115200                = 0x1c200

    class DataBits(enum.Enum):

        Data5                     = 0x5
        Data6                     = 0x6
        Data7                     = 0x7
        Data8                     = 0x8

    class Direction(enum.Flag):

        Input                     = 0x1
        Output                    = 0x2
        AllDirections             = 0x3

    class FlowControl(enum.Enum):

        NoFlowControl             = 0x0
        HardwareControl           = 0x1
        SoftwareControl           = 0x2

    class Parity(enum.Enum):

        NoParity                  = 0x0
        EvenParity                = 0x2
        OddParity                 = 0x3
        SpaceParity               = 0x4
        MarkParity                = 0x5

    class PinoutSignal(enum.Flag):

        NoSignal                  = 0x0
        DataTerminalReadySignal   = 0x4
        DataCarrierDetectSignal   = 0x8
        DataSetReadySignal        = 0x10
        RingIndicatorSignal       = 0x20
        RequestToSendSignal       = 0x40
        ClearToSendSignal         = 0x80
        SecondaryTransmittedDataSignal = 0x100
        SecondaryReceivedDataSignal = 0x200

    class SerialPortError(enum.Enum):

        NoError                   = 0x0
        DeviceNotFoundError       = 0x1
        PermissionError           = 0x2
        OpenError                 = 0x3
        WriteError                = 0x4
        ReadError                 = 0x5
        ResourceError             = 0x6
        UnsupportedOperationError = 0x7
        UnknownError              = 0x8
        TimeoutError              = 0x9
        NotOpenError              = 0xa

    class StopBits(enum.Enum):

        OneStop                   = 0x1
        TwoStop                   = 0x2
        OneAndHalfStop            = 0x3


    @typing.overload
    def __init__(self, info: PySide6.QtSerialPort.QSerialPortInfo, /, parent: PySide6.QtCore.QObject | None = ..., *, baudRate: int | None = ..., dataBits: PySide6.QtSerialPort.QSerialPort.DataBits | None = ..., parity: PySide6.QtSerialPort.QSerialPort.Parity | None = ..., stopBits: PySide6.QtSerialPort.QSerialPort.StopBits | None = ..., flowControl: PySide6.QtSerialPort.QSerialPort.FlowControl | None = ..., dataTerminalReady: bool | None = ..., requestToSend: bool | None = ..., error: PySide6.QtSerialPort.QSerialPort.SerialPortError | None = ..., breakEnabled: bool | None = ..., settingsRestoredOnClose: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, name: str, /, parent: PySide6.QtCore.QObject | None = ..., *, baudRate: int | None = ..., dataBits: PySide6.QtSerialPort.QSerialPort.DataBits | None = ..., parity: PySide6.QtSerialPort.QSerialPort.Parity | None = ..., stopBits: PySide6.QtSerialPort.QSerialPort.StopBits | None = ..., flowControl: PySide6.QtSerialPort.QSerialPort.FlowControl | None = ..., dataTerminalReady: bool | None = ..., requestToSend: bool | None = ..., error: PySide6.QtSerialPort.QSerialPort.SerialPortError | None = ..., breakEnabled: bool | None = ..., settingsRestoredOnClose: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, baudRate: int | None = ..., dataBits: PySide6.QtSerialPort.QSerialPort.DataBits | None = ..., parity: PySide6.QtSerialPort.QSerialPort.Parity | None = ..., stopBits: PySide6.QtSerialPort.QSerialPort.StopBits | None = ..., flowControl: PySide6.QtSerialPort.QSerialPort.FlowControl | None = ..., dataTerminalReady: bool | None = ..., requestToSend: bool | None = ..., error: PySide6.QtSerialPort.QSerialPort.SerialPortError | None = ..., breakEnabled: bool | None = ..., settingsRestoredOnClose: bool | None = ...) -> None: ...

    def baudRate(self, /, directions: PySide6.QtSerialPort.QSerialPort.Direction = ...) -> int: ...
    def bytesAvailable(self, /) -> int: ...
    def bytesToWrite(self, /) -> int: ...
    def canReadLine(self, /) -> bool: ...
    def clear(self, /, directions: PySide6.QtSerialPort.QSerialPort.Direction = ...) -> bool: ...
    def clearError(self, /) -> None: ...
    def close(self, /) -> None: ...
    def dataBits(self, /) -> PySide6.QtSerialPort.QSerialPort.DataBits: ...
    def error(self, /) -> PySide6.QtSerialPort.QSerialPort.SerialPortError: ...
    def flowControl(self, /) -> PySide6.QtSerialPort.QSerialPort.FlowControl: ...
    def flush(self, /) -> bool: ...
    def handle(self, /) -> int: ...
    def isBreakEnabled(self, /) -> bool: ...
    def isDataTerminalReady(self, /) -> bool: ...
    def isRequestToSend(self, /) -> bool: ...
    def isSequential(self, /) -> bool: ...
    def open(self, mode: PySide6.QtCore.QIODeviceBase.OpenModeFlag, /) -> bool: ...
    def parity(self, /) -> PySide6.QtSerialPort.QSerialPort.Parity: ...
    def pinoutSignals(self, /) -> PySide6.QtSerialPort.QSerialPort.PinoutSignal: ...
    def portName(self, /) -> str: ...
    def readBufferSize(self, /) -> int: ...
    def readData(self, maxSize: int, /) -> object: ...
    def readLineData(self, maxSize: int, /) -> object: ...
    def setBaudRate(self, baudRate: int, /, directions: PySide6.QtSerialPort.QSerialPort.Direction = ...) -> bool: ...
    def setBreakEnabled(self, /, set: bool = ...) -> bool: ...
    def setDataBits(self, dataBits: PySide6.QtSerialPort.QSerialPort.DataBits, /) -> bool: ...
    def setDataTerminalReady(self, set: bool, /) -> bool: ...
    def setFlowControl(self, flowControl: PySide6.QtSerialPort.QSerialPort.FlowControl, /) -> bool: ...
    def setParity(self, parity: PySide6.QtSerialPort.QSerialPort.Parity, /) -> bool: ...
    def setPort(self, info: PySide6.QtSerialPort.QSerialPortInfo, /) -> None: ...
    def setPortName(self, name: str, /) -> None: ...
    def setReadBufferSize(self, size: int, /) -> None: ...
    def setRequestToSend(self, set: bool, /) -> bool: ...
    def setSettingsRestoredOnClose(self, restore: bool, /) -> None: ...
    def setStopBits(self, stopBits: PySide6.QtSerialPort.QSerialPort.StopBits, /) -> bool: ...
    def setWriteBufferSize(self, size: int, /) -> None: ...
    def settingsRestoredOnClose(self, /) -> bool: ...
    def stopBits(self, /) -> PySide6.QtSerialPort.QSerialPort.StopBits: ...
    def waitForBytesWritten(self, /, msecs: int = ...) -> bool: ...
    def waitForReadyRead(self, /, msecs: int = ...) -> bool: ...
    def writeBufferSize(self, /) -> int: ...
    def writeData(self, data: bytes | bytearray | memoryview, maxSize: int, /) -> int: ...


class QSerialPortInfo(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, port: PySide6.QtSerialPort.QSerialPort, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtSerialPort.QSerialPortInfo, /) -> None: ...
    @typing.overload
    def __init__(self, name: str, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    @staticmethod
    def availablePorts() -> typing.List[PySide6.QtSerialPort.QSerialPortInfo]: ...
    def description(self, /) -> str: ...
    def hasProductIdentifier(self, /) -> bool: ...
    def hasVendorIdentifier(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def manufacturer(self, /) -> str: ...
    def portName(self, /) -> str: ...
    def productIdentifier(self, /) -> int: ...
    def serialNumber(self, /) -> str: ...
    @staticmethod
    def standardBaudRates() -> typing.List[int]: ...
    def swap(self, other: PySide6.QtSerialPort.QSerialPortInfo, /) -> None: ...
    def systemLocation(self, /) -> str: ...
    def vendorIdentifier(self, /) -> int: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtSerialBus, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtSerialBus`

import PySide6.QtSerialBus
import PySide6.QtCore
import PySide6.QtNetwork

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QCanBus(PySide6.QtCore.QObject):
    @typing.overload
    def availableDevices(self, /) -> tuple: ...
    @typing.overload
    def availableDevices(self, plugin: str, /) -> tuple: ...
    def createDevice(self, plugin: str, interfaceName: str, /) -> tuple: ...
    @staticmethod
    def instance() -> PySide6.QtSerialBus.QCanBus: ...
    def plugins(self, /) -> typing.List[str]: ...


class QCanBusDevice(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QCanBusDevice::CanBusError)
    framesReceived           : typing.ClassVar[Signal] = ... # framesReceived()
    framesWritten            : typing.ClassVar[Signal] = ... # framesWritten(qlonglong)
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QCanBusDevice::CanBusDeviceState)

    class CanBusDeviceState(enum.Enum):

        UnconnectedState          = 0x0
        ConnectingState           = 0x1
        ConnectedState            = 0x2
        ClosingState              = 0x3

    class CanBusError(enum.Enum):

        NoError                   = 0x0
        ReadError                 = 0x1
        WriteError                = 0x2
        ConnectionError           = 0x3
        ConfigurationError        = 0x4
        UnknownError              = 0x5
        OperationError            = 0x6
        TimeoutError              = 0x7

    class CanBusStatus(enum.Enum):

        Unknown                   = 0x0
        Good                      = 0x1
        Warning                   = 0x2
        Error                     = 0x3
        BusOff                    = 0x4

    class ConfigurationKey(enum.Enum):

        RawFilterKey              = 0x0
        ErrorFilterKey            = 0x1
        LoopbackKey               = 0x2
        ReceiveOwnKey             = 0x3
        BitRateKey                = 0x4
        CanFdKey                  = 0x5
        DataBitRateKey            = 0x6
        ProtocolKey               = 0x7
        UserKey                   = 0x1e

    class Direction(enum.Flag):

        Input                     = 0x1
        Output                    = 0x2
        AllDirections             = 0x3

    class Filter(Shiboken.Object):

        format                    = ...  # type: PySide6.QtSerialBus.QCanBusDevice.Filter.FormatFilter
        frameId                   = ...  # type: typing.Any
        frameIdMask               = ...  # type: typing.Any
        type                      = ...  # type: PySide6.QtSerialBus.QCanBusFrame.FrameType

        class FormatFilter(enum.Flag):

            MatchBaseFormat           = 0x1
            MatchExtendedFormat       = 0x2
            MatchBaseAndExtendedFormat = 0x3


        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, Filter: PySide6.QtSerialBus.QCanBusDevice.Filter, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def __eq__(self, b: PySide6.QtSerialBus.QCanBusDevice.Filter, /) -> bool: ...
        def __ne__(self, b: PySide6.QtSerialBus.QCanBusDevice.Filter, /) -> bool: ...


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def busStatus(self, /) -> PySide6.QtSerialBus.QCanBusDevice.CanBusStatus: ...
    def clear(self, /, direction: PySide6.QtSerialBus.QCanBusDevice.Direction = ...) -> None: ...
    def clearError(self, /) -> None: ...
    def close(self, /) -> None: ...
    def configurationKeys(self, /) -> typing.List[PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey]: ...
    def configurationParameter(self, key: PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey, /) -> typing.Any: ...
    def connectDevice(self, /) -> bool: ...
    @typing.overload
    @staticmethod
    def createDeviceInfo(plugin: str, name: str, serialNumber: str, description: str, alias: str, channel: int, isVirtual: bool, isFlexibleDataRateCapable: bool, /) -> PySide6.QtSerialBus.QCanBusDeviceInfo: ...
    @typing.overload
    @staticmethod
    def createDeviceInfo(plugin: str, name: str, isVirtual: bool, isFlexibleDataRateCapable: bool, /) -> PySide6.QtSerialBus.QCanBusDeviceInfo: ...
    def dequeueOutgoingFrame(self, /) -> PySide6.QtSerialBus.QCanBusFrame: ...
    def deviceInfo(self, /) -> PySide6.QtSerialBus.QCanBusDeviceInfo: ...
    def disconnectDevice(self, /) -> None: ...
    def enqueueOutgoingFrame(self, newFrame: PySide6.QtSerialBus.QCanBusFrame | PySide6.QtSerialBus.QCanBusFrame.FrameType, /) -> None: ...
    def enqueueReceivedFrames(self, newFrames: collections.abc.Sequence[PySide6.QtSerialBus.QCanBusFrame], /) -> None: ...
    def error(self, /) -> PySide6.QtSerialBus.QCanBusDevice.CanBusError: ...
    def errorString(self, /) -> str: ...
    def framesAvailable(self, /) -> int: ...
    def framesToWrite(self, /) -> int: ...
    def hasBusStatus(self, /) -> bool: ...
    def hasOutgoingFrames(self, /) -> bool: ...
    def interpretErrorFrame(self, errorFrame: PySide6.QtSerialBus.QCanBusFrame | PySide6.QtSerialBus.QCanBusFrame.FrameType, /) -> str: ...
    def open(self, /) -> bool: ...
    def readAllFrames(self, /) -> typing.List[PySide6.QtSerialBus.QCanBusFrame]: ...
    def readFrame(self, /) -> PySide6.QtSerialBus.QCanBusFrame: ...
    def resetController(self, /) -> None: ...
    def setConfigurationParameter(self, key: PySide6.QtSerialBus.QCanBusDevice.ConfigurationKey, value: typing.Any, /) -> None: ...
    def setError(self, errorText: str, arg__2: PySide6.QtSerialBus.QCanBusDevice.CanBusError, /) -> None: ...
    def setState(self, newState: PySide6.QtSerialBus.QCanBusDevice.CanBusDeviceState, /) -> None: ...
    def state(self, /) -> PySide6.QtSerialBus.QCanBusDevice.CanBusDeviceState: ...
    def waitForFramesReceived(self, msecs: int, /) -> bool: ...
    def waitForFramesWritten(self, msecs: int, /) -> bool: ...
    def writeFrame(self, frame: PySide6.QtSerialBus.QCanBusFrame | PySide6.QtSerialBus.QCanBusFrame.FrameType, /) -> bool: ...


class QCanBusDeviceInfo(Shiboken.Object):

    def __init__(self, other: PySide6.QtSerialBus.QCanBusDeviceInfo, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def alias(self, /) -> str: ...
    def channel(self, /) -> int: ...
    def description(self, /) -> str: ...
    def hasFlexibleDataRate(self, /) -> bool: ...
    def isVirtual(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def plugin(self, /) -> str: ...
    def serialNumber(self, /) -> str: ...


class QCanBusFactory(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def availableDevices(self, /) -> typing.Tuple[typing.List[PySide6.QtSerialBus.QCanBusDeviceInfo], str]: ...
    def createDevice(self, interfaceName: str, /) -> typing.Tuple[PySide6.QtSerialBus.QCanBusDevice, str]: ...


class QCanBusFrame(Shiboken.Object):

    class FrameError(enum.Flag):

        NoError                   = 0x0
        TransmissionTimeoutError  = 0x1
        LostArbitrationError      = 0x2
        ControllerError           = 0x4
        ProtocolViolationError    = 0x8
        TransceiverError          = 0x10
        MissingAcknowledgmentError = 0x20
        BusOffError               = 0x40
        BusError                  = 0x80
        ControllerRestartError    = 0x100
        UnknownError              = 0x200
        AnyError                  = 0x1fffffff

    class FrameType(enum.Enum):

        UnknownFrame              = 0x0
        DataFrame                 = 0x1
        ErrorFrame                = 0x2
        RemoteRequestFrame        = 0x3
        InvalidFrame              = 0x4

    class TimeStamp(Shiboken.Object):

        @typing.overload
        def __init__(self, TimeStamp: PySide6.QtSerialBus.QCanBusFrame.TimeStamp, /) -> None: ...
        @typing.overload
        def __init__(self, /, s: int | None = ..., usec: int | None = ...) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        @staticmethod
        def fromMicroSeconds(usec: int, /) -> PySide6.QtSerialBus.QCanBusFrame.TimeStamp: ...
        def microSeconds(self, /) -> int: ...
        def seconds(self, /) -> int: ...


    @typing.overload
    def __init__(self, /, type: PySide6.QtSerialBus.QCanBusFrame.FrameType = ...) -> None: ...
    @typing.overload
    def __init__(self, QCanBusFrame: PySide6.QtSerialBus.QCanBusFrame, /) -> None: ...
    @typing.overload
    def __init__(self, identifier: int, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __lshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __rshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def error(self, /) -> PySide6.QtSerialBus.QCanBusFrame.FrameError: ...
    def frameId(self, /) -> int: ...
    def frameType(self, /) -> PySide6.QtSerialBus.QCanBusFrame.FrameType: ...
    def hasBitrateSwitch(self, /) -> bool: ...
    def hasErrorStateIndicator(self, /) -> bool: ...
    def hasExtendedFrameFormat(self, /) -> bool: ...
    def hasFlexibleDataRateFormat(self, /) -> bool: ...
    def hasLocalEcho(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def payload(self, /) -> PySide6.QtCore.QByteArray: ...
    def setBitrateSwitch(self, bitrateSwitch: bool, /) -> None: ...
    def setError(self, e: PySide6.QtSerialBus.QCanBusFrame.FrameError, /) -> None: ...
    def setErrorStateIndicator(self, errorStateIndicator: bool, /) -> None: ...
    def setExtendedFrameFormat(self, isExtended: bool, /) -> None: ...
    def setFlexibleDataRateFormat(self, isFlexibleData: bool, /) -> None: ...
    def setFrameId(self, newFrameId: int, /) -> None: ...
    def setFrameType(self, newFormat: PySide6.QtSerialBus.QCanBusFrame.FrameType, /) -> None: ...
    def setLocalEcho(self, localEcho: bool, /) -> None: ...
    def setPayload(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def setTimeStamp(self, ts: PySide6.QtSerialBus.QCanBusFrame.TimeStamp, /) -> None: ...
    def timeStamp(self, /) -> PySide6.QtSerialBus.QCanBusFrame.TimeStamp: ...
    def toString(self, /) -> str: ...


class QCanDbcFileParser(Shiboken.Object):

    class Error(enum.Enum):

        None_                     = 0x0
        FileReading               = 0x1
        Parsing                   = 0x2


    def __init__(self, /) -> None: ...

    def error(self, /) -> PySide6.QtSerialBus.QCanDbcFileParser.Error: ...
    def errorString(self, /) -> str: ...
    def messageDescriptions(self, /) -> typing.List[PySide6.QtSerialBus.QCanMessageDescription]: ...
    def messageValueDescriptions(self, /) -> typing.Dict[PySide6.QtSerialBus.QtCanBus.UniqueId, typing.Dict[str, typing.Dict[int, str]]]: ...
    @typing.overload
    def parse(self, fileName: str, /) -> bool: ...
    @typing.overload
    def parse(self, fileNames: collections.abc.Sequence[str], /) -> bool: ...
    def parseData(self, data: str, /) -> bool: ...
    @staticmethod
    def uniqueIdDescription() -> PySide6.QtSerialBus.QCanUniqueIdDescription: ...
    def warnings(self, /) -> typing.List[str]: ...


class QCanFrameProcessor(Shiboken.Object):

    class Error(enum.Enum):

        None_                     = 0x0
        InvalidFrame              = 0x1
        UnsupportedFrameFormat    = 0x2
        Decoding                  = 0x3
        Encoding                  = 0x4

    class ParseResult(Shiboken.Object):

        signalValues              = ...  # type: typing.Dict[str, typing.Any]
        uniqueId                  = ...  # type: PySide6.QtSerialBus.QtCanBus.UniqueId

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, ParseResult: PySide6.QtSerialBus.QCanFrameProcessor.ParseResult, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...


    def __init__(self, /) -> None: ...

    def addMessageDescriptions(self, descriptions: collections.abc.Sequence[PySide6.QtSerialBus.QCanMessageDescription], /) -> None: ...
    def clearMessageDescriptions(self, /) -> None: ...
    def error(self, /) -> PySide6.QtSerialBus.QCanFrameProcessor.Error: ...
    def errorString(self, /) -> str: ...
    def messageDescriptions(self, /) -> typing.List[PySide6.QtSerialBus.QCanMessageDescription]: ...
    def parseFrame(self, frame: PySide6.QtSerialBus.QCanBusFrame | PySide6.QtSerialBus.QCanBusFrame.FrameType, /) -> PySide6.QtSerialBus.QCanFrameProcessor.ParseResult: ...
    def prepareFrame(self, uniqueId: PySide6.QtSerialBus.QtCanBus.UniqueId, signalValues: typing.Dict[str, typing.Any], /) -> PySide6.QtSerialBus.QCanBusFrame: ...
    def setMessageDescriptions(self, descriptions: collections.abc.Sequence[PySide6.QtSerialBus.QCanMessageDescription], /) -> None: ...
    def setUniqueIdDescription(self, description: PySide6.QtSerialBus.QCanUniqueIdDescription, /) -> None: ...
    def uniqueIdDescription(self, /) -> PySide6.QtSerialBus.QCanUniqueIdDescription: ...
    def warnings(self, /) -> typing.List[str]: ...


class QCanMessageDescription(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtSerialBus.QCanMessageDescription, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __repr__(self, /) -> str: ...
    def addSignalDescription(self, description: PySide6.QtSerialBus.QCanSignalDescription, /) -> None: ...
    def clearSignalDescriptions(self, /) -> None: ...
    def comment(self, /) -> str: ...
    def isValid(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def setComment(self, text: str, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def setSignalDescriptions(self, descriptions: collections.abc.Sequence[PySide6.QtSerialBus.QCanSignalDescription], /) -> None: ...
    def setSize(self, size: int, /) -> None: ...
    def setTransmitter(self, transmitter: str, /) -> None: ...
    def setUniqueId(self, id: PySide6.QtSerialBus.QtCanBus.UniqueId, /) -> None: ...
    def signalDescriptionForName(self, name: str, /) -> PySide6.QtSerialBus.QCanSignalDescription: ...
    def signalDescriptions(self, /) -> typing.List[PySide6.QtSerialBus.QCanSignalDescription]: ...
    def size(self, /) -> int: ...
    def swap(self, other: PySide6.QtSerialBus.QCanMessageDescription, /) -> None: ...
    def transmitter(self, /) -> str: ...
    def uniqueId(self, /) -> PySide6.QtSerialBus.QtCanBus.UniqueId: ...


class QCanSignalDescription(Shiboken.Object):

    class MultiplexValueRange(Shiboken.Object):

        maximum                   = ...  # type: typing.Any
        minimum                   = ...  # type: typing.Any

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, MultiplexValueRange: PySide6.QtSerialBus.QCanSignalDescription.MultiplexValueRange, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def __eq__(self, rhs: PySide6.QtSerialBus.QCanSignalDescription.MultiplexValueRange, /) -> bool: ...
        def __ne__(self, rhs: PySide6.QtSerialBus.QCanSignalDescription.MultiplexValueRange, /) -> bool: ...
        def __repr__(self, /) -> str: ...


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtSerialBus.QCanSignalDescription, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __repr__(self, /) -> str: ...
    @typing.overload
    def addMultiplexSignal(self, name: str, ranges: collections.abc.Sequence[PySide6.QtSerialBus.QCanSignalDescription.MultiplexValueRange], /) -> None: ...
    @typing.overload
    def addMultiplexSignal(self, name: str, value: typing.Any, /) -> None: ...
    def bitLength(self, /) -> int: ...
    def clearMultiplexSignals(self, /) -> None: ...
    def comment(self, /) -> str: ...
    def dataEndian(self, /) -> PySide6.QtCore.QSysInfo.Endian: ...
    def dataFormat(self, /) -> PySide6.QtSerialBus.QtCanBus.DataFormat: ...
    def dataSource(self, /) -> PySide6.QtSerialBus.QtCanBus.DataSource: ...
    def factor(self, /) -> float: ...
    def isValid(self, /) -> bool: ...
    def maximum(self, /) -> float: ...
    def minimum(self, /) -> float: ...
    def multiplexSignals(self, /) -> typing.Dict[str, typing.List[PySide6.QtSerialBus.QCanSignalDescription.MultiplexValueRange]]: ...
    def multiplexState(self, /) -> PySide6.QtSerialBus.QtCanBus.MultiplexState: ...
    def name(self, /) -> str: ...
    def offset(self, /) -> float: ...
    def physicalUnit(self, /) -> str: ...
    def receiver(self, /) -> str: ...
    def scaling(self, /) -> float: ...
    def setBitLength(self, length: int, /) -> None: ...
    def setComment(self, text: str, /) -> None: ...
    def setDataEndian(self, endian: PySide6.QtCore.QSysInfo.Endian, /) -> None: ...
    def setDataFormat(self, format: PySide6.QtSerialBus.QtCanBus.DataFormat, /) -> None: ...
    def setDataSource(self, source: PySide6.QtSerialBus.QtCanBus.DataSource, /) -> None: ...
    def setFactor(self, factor: float, /) -> None: ...
    def setMultiplexSignals(self, multiplexorSignals: typing.Dict[str, collections.abc.Sequence[PySide6.QtSerialBus.QCanSignalDescription.MultiplexValueRange]], /) -> None: ...
    def setMultiplexState(self, state: PySide6.QtSerialBus.QtCanBus.MultiplexState, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def setOffset(self, offset: float, /) -> None: ...
    def setPhysicalUnit(self, unit: str, /) -> None: ...
    def setRange(self, minimum: float, maximum: float, /) -> None: ...
    def setReceiver(self, receiver: str, /) -> None: ...
    def setScaling(self, scaling: float, /) -> None: ...
    def setStartBit(self, bit: int, /) -> None: ...
    def startBit(self, /) -> int: ...
    def swap(self, other: PySide6.QtSerialBus.QCanSignalDescription, /) -> None: ...


class QCanUniqueIdDescription(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, other: PySide6.QtSerialBus.QCanUniqueIdDescription, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def bitLength(self, /) -> int: ...
    def endian(self, /) -> PySide6.QtCore.QSysInfo.Endian: ...
    def isValid(self, /) -> bool: ...
    def setBitLength(self, length: int, /) -> None: ...
    def setEndian(self, endian: PySide6.QtCore.QSysInfo.Endian, /) -> None: ...
    def setSource(self, source: PySide6.QtSerialBus.QtCanBus.DataSource, /) -> None: ...
    def setStartBit(self, bit: int, /) -> None: ...
    def source(self, /) -> PySide6.QtSerialBus.QtCanBus.DataSource: ...
    def startBit(self, /) -> int: ...
    def swap(self, other: PySide6.QtSerialBus.QCanUniqueIdDescription, /) -> None: ...


class QIntList: ...


class QModbusClient(PySide6.QtSerialBus.QModbusDevice):

    timeoutChanged           : typing.ClassVar[Signal] = ... # timeoutChanged(int)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def numberOfRetries(self, /) -> int: ...
    def processPrivateResponse(self, response: PySide6.QtSerialBus.QModbusResponse, data: PySide6.QtSerialBus.QModbusDataUnit, /) -> bool: ...
    def processResponse(self, response: PySide6.QtSerialBus.QModbusResponse, data: PySide6.QtSerialBus.QModbusDataUnit, /) -> bool: ...
    def sendRawRequest(self, request: PySide6.QtSerialBus.QModbusRequest, serverAddress: int, /) -> PySide6.QtSerialBus.QModbusReply: ...
    def sendReadRequest(self, read: PySide6.QtSerialBus.QModbusDataUnit, serverAddress: int, /) -> PySide6.QtSerialBus.QModbusReply: ...
    def sendReadWriteRequest(self, read: PySide6.QtSerialBus.QModbusDataUnit, write: PySide6.QtSerialBus.QModbusDataUnit, serverAddress: int, /) -> PySide6.QtSerialBus.QModbusReply: ...
    def sendWriteRequest(self, write: PySide6.QtSerialBus.QModbusDataUnit, serverAddress: int, /) -> PySide6.QtSerialBus.QModbusReply: ...
    def setNumberOfRetries(self, number: int, /) -> None: ...
    def setTimeout(self, newTimeout: int, /) -> None: ...
    def timeout(self, /) -> int: ...


class QModbusDataUnit(Shiboken.Object):

    class RegisterType(enum.Enum):

        Invalid                   = 0x0
        DiscreteInputs            = 0x1
        Coils                     = 0x2
        InputRegisters            = 0x3
        HoldingRegisters          = 0x4


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QModbusDataUnit: PySide6.QtSerialBus.QModbusDataUnit, /) -> None: ...
    @typing.overload
    def __init__(self, type: PySide6.QtSerialBus.QModbusDataUnit.RegisterType, /) -> None: ...
    @typing.overload
    def __init__(self, type: PySide6.QtSerialBus.QModbusDataUnit.RegisterType, newStartAddress: int, newValues: collections.abc.Sequence[int], /) -> None: ...
    @typing.overload
    def __init__(self, type: PySide6.QtSerialBus.QModbusDataUnit.RegisterType, newStartAddress: int, newValueCount: int, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def isValid(self, /) -> bool: ...
    def registerType(self, /) -> PySide6.QtSerialBus.QModbusDataUnit.RegisterType: ...
    def setRegisterType(self, type: PySide6.QtSerialBus.QModbusDataUnit.RegisterType, /) -> None: ...
    def setStartAddress(self, newAddress: int, /) -> None: ...
    def setValue(self, index: int, newValue: int, /) -> None: ...
    def setValueCount(self, newCount: int, /) -> None: ...
    def setValues(self, newValues: collections.abc.Sequence[int], /) -> None: ...
    def startAddress(self, /) -> int: ...
    def value(self, index: int, /) -> int: ...
    def valueCount(self, /) -> int: ...
    def values(self, /) -> typing.List[int]: ...


class QModbusDevice(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QModbusDevice::Error)
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged(QModbusDevice::State)

    class ConnectionParameter(enum.Enum):

        SerialPortNameParameter   = 0x0
        SerialParityParameter     = 0x1
        SerialBaudRateParameter   = 0x2
        SerialDataBitsParameter   = 0x3
        SerialStopBitsParameter   = 0x4
        NetworkPortParameter      = 0x5
        NetworkAddressParameter   = 0x6

    class Error(enum.Enum):

        NoError                   = 0x0
        ReadError                 = 0x1
        WriteError                = 0x2
        ConnectionError           = 0x3
        ConfigurationError        = 0x4
        TimeoutError              = 0x5
        ProtocolError             = 0x6
        ReplyAbortedError         = 0x7
        UnknownError              = 0x8
        InvalidResponseError      = 0x9

    class IntermediateError(enum.Enum):

        ResponseCrcError          = 0x0
        ResponseRequestMismatch   = 0x1

    class State(enum.Enum):

        UnconnectedState          = 0x0
        ConnectingState           = 0x1
        ConnectedState            = 0x2
        ClosingState              = 0x3


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def close(self, /) -> None: ...
    def connectDevice(self, /) -> bool: ...
    def connectionParameter(self, parameter: PySide6.QtSerialBus.QModbusDevice.ConnectionParameter, /) -> typing.Any: ...
    def device(self, /) -> PySide6.QtCore.QIODevice: ...
    def disconnectDevice(self, /) -> None: ...
    def error(self, /) -> PySide6.QtSerialBus.QModbusDevice.Error: ...
    def errorString(self, /) -> str: ...
    def open(self, /) -> bool: ...
    def setConnectionParameter(self, parameter: PySide6.QtSerialBus.QModbusDevice.ConnectionParameter, value: typing.Any, /) -> None: ...
    def setError(self, errorText: str, error: PySide6.QtSerialBus.QModbusDevice.Error, /) -> None: ...
    def setState(self, newState: PySide6.QtSerialBus.QModbusDevice.State, /) -> None: ...
    def state(self, /) -> PySide6.QtSerialBus.QModbusDevice.State: ...


class QModbusDeviceIdentification(Shiboken.Object):

    class ConformityLevel(enum.Enum):

        BasicConformityLevel      = 0x1
        RegularConformityLevel    = 0x2
        ExtendedConformityLevel   = 0x3
        BasicIndividualConformityLevel = 0x81
        RegularIndividualConformityLevel = 0x82
        ExtendedIndividualConformityLevel = 0x83

    class ObjectId(enum.Enum):

        VendorNameObjectId        = 0x0
        ProductCodeObjectId       = 0x1
        MajorMinorRevisionObjectId = 0x2
        VendorUrlObjectId         = 0x3
        ProductNameObjectId       = 0x4
        ModelNameObjectId         = 0x5
        UserApplicationNameObjectId = 0x6
        ReservedObjectId          = 0x7
        ProductDependentObjectId  = 0x80
        UndefinedObjectId         = 0x100

    class ReadDeviceIdCode(enum.Enum):

        BasicReadDeviceIdCode     = 0x1
        RegularReadDeviceIdCode   = 0x2
        ExtendedReadDeviceIdCode  = 0x3
        IndividualReadDeviceIdCode = 0x4


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QModbusDeviceIdentification: PySide6.QtSerialBus.QModbusDeviceIdentification, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def conformityLevel(self, /) -> PySide6.QtSerialBus.QModbusDeviceIdentification.ConformityLevel: ...
    def contains(self, objectId: int, /) -> bool: ...
    @staticmethod
    def fromByteArray(ba: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> PySide6.QtSerialBus.QModbusDeviceIdentification: ...
    def insert(self, objectId: int, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def objectIds(self, /) -> typing.List[int]: ...
    def remove(self, objectId: int, /) -> None: ...
    def setConformityLevel(self, level: PySide6.QtSerialBus.QModbusDeviceIdentification.ConformityLevel, /) -> None: ...
    def value(self, objectId: int, /) -> PySide6.QtCore.QByteArray: ...


class QModbusExceptionResponse(PySide6.QtSerialBus.QModbusResponse):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, fc: PySide6.QtSerialBus.QModbusPdu.FunctionCode, ec: PySide6.QtSerialBus.QModbusPdu.ExceptionCode, /) -> None: ...
    @typing.overload
    def __init__(self, pdu: PySide6.QtSerialBus.QModbusPdu, /) -> None: ...

    def setExceptionCode(self, ec: PySide6.QtSerialBus.QModbusPdu.ExceptionCode, /) -> None: ...
    def setFunctionCode(self, c: PySide6.QtSerialBus.QModbusPdu.FunctionCode, /) -> None: ...


class QModbusPdu(Shiboken.Object):

    class ExceptionCode(enum.Enum):

        IllegalFunction           = 0x1
        IllegalDataAddress        = 0x2
        IllegalDataValue          = 0x3
        ServerDeviceFailure       = 0x4
        Acknowledge               = 0x5
        ServerDeviceBusy          = 0x6
        NegativeAcknowledge       = 0x7
        MemoryParityError         = 0x8
        GatewayPathUnavailable    = 0xa
        GatewayTargetDeviceFailedToRespond = 0xb
        ExtendedException         = 0xff

    class FunctionCode(enum.Enum):

        Invalid                   = 0x0
        ReadCoils                 = 0x1
        ReadDiscreteInputs        = 0x2
        ReadHoldingRegisters      = 0x3
        ReadInputRegisters        = 0x4
        WriteSingleCoil           = 0x5
        WriteSingleRegister       = 0x6
        ReadExceptionStatus       = 0x7
        Diagnostics               = 0x8
        GetCommEventCounter       = 0xb
        GetCommEventLog           = 0xc
        WriteMultipleCoils        = 0xf
        WriteMultipleRegisters    = 0x10
        ReportServerId            = 0x11
        ReadFileRecord            = 0x14
        WriteFileRecord           = 0x15
        MaskWriteRegister         = 0x16
        ReadWriteMultipleRegisters = 0x17
        ReadFifoQueue             = 0x18
        EncapsulatedInterfaceTransport = 0x2b
        UndefinedFunctionCode     = 0x100


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, code: PySide6.QtSerialBus.QModbusPdu.FunctionCode, newData: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtSerialBus.QModbusPdu, /) -> None: ...

    def __lshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __repr__(self, /) -> str: ...
    def data(self, /) -> PySide6.QtCore.QByteArray: ...
    def dataSize(self, /) -> int: ...
    def exceptionCode(self, /) -> PySide6.QtSerialBus.QModbusPdu.ExceptionCode: ...
    def functionCode(self, /) -> PySide6.QtSerialBus.QModbusPdu.FunctionCode: ...
    def isException(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def setData(self, newData: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def setFunctionCode(self, code: PySide6.QtSerialBus.QModbusPdu.FunctionCode, /) -> None: ...
    def size(self, /) -> int: ...


class QModbusReply(PySide6.QtCore.QObject):

    errorOccurred            : typing.ClassVar[Signal] = ... # errorOccurred(QModbusDevice::Error)
    finished                 : typing.ClassVar[Signal] = ... # finished()
    intermediateErrorOccurred: typing.ClassVar[Signal] = ... # intermediateErrorOccurred(QModbusDevice::IntermediateError)

    class ReplyType(enum.Enum):

        Raw                       = 0x0
        Common                    = 0x1
        Broadcast                 = 0x2


    def __init__(self, type: PySide6.QtSerialBus.QModbusReply.ReplyType, serverAddress: int, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def addIntermediateError(self, error: PySide6.QtSerialBus.QModbusDevice.IntermediateError, /) -> None: ...
    def error(self, /) -> PySide6.QtSerialBus.QModbusDevice.Error: ...
    def errorString(self, /) -> str: ...
    def intermediateErrors(self, /) -> typing.List[PySide6.QtSerialBus.QModbusDevice.IntermediateError]: ...
    def isFinished(self, /) -> bool: ...
    def rawResult(self, /) -> PySide6.QtSerialBus.QModbusResponse: ...
    def result(self, /) -> PySide6.QtSerialBus.QModbusDataUnit: ...
    def serverAddress(self, /) -> int: ...
    def setError(self, error: PySide6.QtSerialBus.QModbusDevice.Error, errorText: str, /) -> None: ...
    def setFinished(self, isFinished: bool, /) -> None: ...
    def setRawResult(self, unit: PySide6.QtSerialBus.QModbusResponse, /) -> None: ...
    def setResult(self, unit: PySide6.QtSerialBus.QModbusDataUnit, /) -> None: ...
    def type(self, /) -> PySide6.QtSerialBus.QModbusReply.ReplyType: ...


class QModbusRequest(PySide6.QtSerialBus.QModbusPdu):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, code: PySide6.QtSerialBus.QModbusPdu.FunctionCode, /, newData: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview = ...) -> None: ...
    @typing.overload
    def __init__(self, pdu: PySide6.QtSerialBus.QModbusPdu, /) -> None: ...

    def __lshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __rshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    @staticmethod
    def calculateDataSize(pdu: PySide6.QtSerialBus.QModbusRequest, /) -> int: ...
    @staticmethod
    def minimumDataSize(pdu: PySide6.QtSerialBus.QModbusRequest, /) -> int: ...


class QModbusResponse(PySide6.QtSerialBus.QModbusPdu):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, code: PySide6.QtSerialBus.QModbusPdu.FunctionCode, /, newData: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview = ...) -> None: ...
    @typing.overload
    def __init__(self, pdu: PySide6.QtSerialBus.QModbusPdu, /) -> None: ...

    def __lshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __rshift__(self, stream: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    @staticmethod
    def calculateDataSize(pdu: PySide6.QtSerialBus.QModbusResponse, /) -> int: ...
    @staticmethod
    def minimumDataSize(pdu: PySide6.QtSerialBus.QModbusResponse, /) -> int: ...


class QModbusRtuSerialClient(PySide6.QtSerialBus.QModbusClient):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def close(self, /) -> None: ...
    def interFrameDelay(self, /) -> int: ...
    def open(self, /) -> bool: ...
    def setInterFrameDelay(self, microseconds: int, /) -> None: ...
    def setTurnaroundDelay(self, turnaroundDelay: int, /) -> None: ...
    def turnaroundDelay(self, /) -> int: ...


class QModbusRtuSerialServer(PySide6.QtSerialBus.QModbusServer):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def close(self, /) -> None: ...
    def interFrameDelay(self, /) -> int: ...
    def open(self, /) -> bool: ...
    def processRequest(self, request: PySide6.QtSerialBus.QModbusPdu, /) -> PySide6.QtSerialBus.QModbusResponse: ...
    def processesBroadcast(self, /) -> bool: ...
    def setInterFrameDelay(self, microseconds: int, /) -> None: ...


class QModbusServer(PySide6.QtSerialBus.QModbusDevice):

    dataWritten              : typing.ClassVar[Signal] = ... # dataWritten(QModbusDataUnit::RegisterType,int,int)

    class Option(enum.Enum):

        DiagnosticRegister        = 0x0
        ExceptionStatusOffset     = 0x1
        DeviceBusy                = 0x2
        AsciiInputDelimiter       = 0x3
        ListenOnlyMode            = 0x4
        ServerIdentifier          = 0x5
        RunIndicatorStatus        = 0x6
        AdditionalData            = 0x7
        DeviceIdentification      = 0x8
        UserOption                = 0x100


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    @typing.overload
    def data(self, newData: PySide6.QtSerialBus.QModbusDataUnit, /) -> bool: ...
    @typing.overload
    def data(self, table: PySide6.QtSerialBus.QModbusDataUnit.RegisterType, address: int, /) -> typing.Tuple[bool, int]: ...
    def processPrivateRequest(self, request: PySide6.QtSerialBus.QModbusPdu, /) -> PySide6.QtSerialBus.QModbusResponse: ...
    def processRequest(self, request: PySide6.QtSerialBus.QModbusPdu, /) -> PySide6.QtSerialBus.QModbusResponse: ...
    def processesBroadcast(self, /) -> bool: ...
    def readData(self, newData: PySide6.QtSerialBus.QModbusDataUnit, /) -> bool: ...
    def serverAddress(self, /) -> int: ...
    @typing.overload
    def setData(self, unit: PySide6.QtSerialBus.QModbusDataUnit, /) -> bool: ...
    @typing.overload
    def setData(self, table: PySide6.QtSerialBus.QModbusDataUnit.RegisterType, address: int, data: int, /) -> bool: ...
    def setMap(self, map: typing.Dict[PySide6.QtSerialBus.QModbusDataUnit.RegisterType, PySide6.QtSerialBus.QModbusDataUnit], /) -> bool: ...
    def setServerAddress(self, serverAddress: int, /) -> None: ...
    def setValue(self, option: int, value: typing.Any, /) -> bool: ...
    def value(self, option: int, /) -> typing.Any: ...
    def writeData(self, unit: PySide6.QtSerialBus.QModbusDataUnit, /) -> bool: ...


class QModbusTcpClient(PySide6.QtSerialBus.QModbusClient):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def close(self, /) -> None: ...
    def open(self, /) -> bool: ...


class QModbusTcpConnectionObserver(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def acceptNewConnection(self, newClient: PySide6.QtNetwork.QTcpSocket, /) -> bool: ...


class QModbusTcpServer(PySide6.QtSerialBus.QModbusServer):

    modbusClientDisconnected : typing.ClassVar[Signal] = ... # modbusClientDisconnected(QTcpSocket*)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def close(self, /) -> None: ...
    def installConnectionObserver(self, observer: PySide6.QtSerialBus.QModbusTcpConnectionObserver, /) -> None: ...
    def open(self, /) -> bool: ...
    def processRequest(self, request: PySide6.QtSerialBus.QModbusPdu, /) -> PySide6.QtSerialBus.QModbusResponse: ...


class QtCanBus(Shiboken.Object):

    class DataFormat(enum.Enum):

        SignedInteger             = 0x0
        UnsignedInteger           = 0x1
        Float                     = 0x2
        Double                    = 0x3
        AsciiString               = 0x4

    class DataSource(enum.Enum):

        Payload                   = 0x0
        FrameId                   = 0x1

    class MultiplexState(enum.Enum):

        None_                     = 0x0
        MultiplexorSwitch         = 0x1
        MultiplexedSignal         = 0x2
        SwitchAndSignal           = 0x3

    class UniqueId(enum.Enum): ...  # type: ignore[misc]


    @staticmethod
    def qbswap(src: PySide6.QtSerialBus.QtCanBus.UniqueId, /) -> PySide6.QtSerialBus.QtCanBus.UniqueId: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtQuick3D, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtQuick3D`

import PySide6.QtQuick3D
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtQml

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QQuick3D(Shiboken.Object):

    def __init__(self, /) -> None: ...

    @staticmethod
    def idealSurfaceFormat(samples: int = ...) -> PySide6.QtGui.QSurfaceFormat: ...


class QQuick3DGeometry(PySide6.QtQuick3D.QQuick3DObject):

    geometryChanged          : typing.ClassVar[Signal] = ... # geometryChanged()
    geometryNodeDirty        : typing.ClassVar[Signal] = ... # geometryNodeDirty()

    class Attribute(Shiboken.Object):

        componentType             = ...  # type: int
        offset                    = ...  # type: int
        semantic                  = ...  # type: int

        class ComponentType(enum.Enum):

            U16Type                   = 0x0
            U32Type                   = 0x1
            I32Type                   = 0x2
            F32Type                   = 0x3

        class Semantic(enum.Enum):

            IndexSemantic             = 0x0
            PositionSemantic          = 0x1
            NormalSemantic            = 0x2
            TexCoord0Semantic         = 0x3
            TexCoordSemantic          = 0x3
            TangentSemantic           = 0x4
            BinormalSemantic          = 0x5
            JointSemantic             = 0x6
            WeightSemantic            = 0x7
            ColorSemantic             = 0x8
            TargetPositionSemantic    = 0x9
            TargetNormalSemantic      = 0xa
            TargetTangentSemantic     = 0xb
            TargetBinormalSemantic    = 0xc
            TexCoord1Semantic         = 0xd


        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, Attribute: PySide6.QtQuick3D.QQuick3DGeometry.Attribute, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...

    class PrimitiveType(enum.Enum):

        Points                    = 0x0
        LineStrip                 = 0x1
        Lines                     = 0x2
        TriangleStrip             = 0x3
        TriangleFan               = 0x4
        Triangles                 = 0x5

    class TargetAttribute(Shiboken.Object):

        attr                      = ...  # type: PySide6.QtQuick3D.QQuick3DGeometry.Attribute
        stride                    = ...  # type: int
        targetId                  = ...  # type: int

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, TargetAttribute: PySide6.QtQuick3D.QQuick3DGeometry.TargetAttribute, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...


    def __init__(self, /, parent: PySide6.QtQuick3D.QQuick3DObject | None = ...) -> None: ...

    @typing.overload
    def addAttribute(self, att: PySide6.QtQuick3D.QQuick3DGeometry.Attribute, /) -> None: ...
    @typing.overload
    def addAttribute(self, semantic: PySide6.QtQuick3D.QQuick3DGeometry.Attribute.Semantic, offset: int, componentType: PySide6.QtQuick3D.QQuick3DGeometry.Attribute.ComponentType, /) -> None: ...
    def addSubset(self, offset: int, count: int, boundsMin: PySide6.QtGui.QVector3D, boundsMax: PySide6.QtGui.QVector3D, /, name: str = ...) -> None: ...
    @typing.overload
    def addTargetAttribute(self, att: PySide6.QtQuick3D.QQuick3DGeometry.TargetAttribute, /) -> None: ...
    @typing.overload
    def addTargetAttribute(self, targetId: int, semantic: PySide6.QtQuick3D.QQuick3DGeometry.Attribute.Semantic, offset: int, /, stride: int | None = ...) -> None: ...
    def attribute(self, index: int, /) -> PySide6.QtQuick3D.QQuick3DGeometry.Attribute: ...
    def attributeCount(self, /) -> int: ...
    def boundsMax(self, /) -> PySide6.QtGui.QVector3D: ...
    def boundsMin(self, /) -> PySide6.QtGui.QVector3D: ...
    def clear(self, /) -> None: ...
    def indexData(self, /) -> PySide6.QtCore.QByteArray: ...
    def markAllDirty(self, /) -> None: ...
    def primitiveType(self, /) -> PySide6.QtQuick3D.QQuick3DGeometry.PrimitiveType: ...
    def setBounds(self, min: PySide6.QtGui.QVector3D, max: PySide6.QtGui.QVector3D, /) -> None: ...
    @typing.overload
    def setIndexData(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def setIndexData(self, offset: int, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def setPrimitiveType(self, type: PySide6.QtQuick3D.QQuick3DGeometry.PrimitiveType, /) -> None: ...
    def setStride(self, stride: int, /) -> None: ...
    @typing.overload
    def setTargetData(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def setTargetData(self, offset: int, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def setVertexData(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def setVertexData(self, offset: int, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def stride(self, /) -> int: ...
    def subsetBoundsMax(self, subset: int, /) -> PySide6.QtGui.QVector3D: ...
    def subsetBoundsMin(self, subset: int, /) -> PySide6.QtGui.QVector3D: ...
    @typing.overload
    def subsetCount(self, /) -> int: ...
    @typing.overload
    def subsetCount(self, subset: int, /) -> int: ...
    def subsetName(self, subset: int, /) -> str: ...
    def subsetOffset(self, subset: int, /) -> int: ...
    def targetAttribute(self, index: int, /) -> PySide6.QtQuick3D.QQuick3DGeometry.TargetAttribute: ...
    def targetAttributeCount(self, /) -> int: ...
    def targetData(self, /) -> PySide6.QtCore.QByteArray: ...
    def vertexData(self, /) -> PySide6.QtCore.QByteArray: ...


class QQuick3DInstancing(PySide6.QtQuick3D.QQuick3DObject):

    depthSortingEnabledChanged: typing.ClassVar[Signal] = ... # depthSortingEnabledChanged()
    hasTransparencyChanged   : typing.ClassVar[Signal] = ... # hasTransparencyChanged()
    instanceCountOverrideChanged: typing.ClassVar[Signal] = ... # instanceCountOverrideChanged()
    instanceNodeDirty        : typing.ClassVar[Signal] = ... # instanceNodeDirty()
    instanceTableChanged     : typing.ClassVar[Signal] = ... # instanceTableChanged()
    shadowBoundsMaximumChanged: typing.ClassVar[Signal] = ... # shadowBoundsMaximumChanged()
    shadowBoundsMinimumChanged: typing.ClassVar[Signal] = ... # shadowBoundsMinimumChanged()

    class InstanceTableEntry(Shiboken.Object):

        color                     = ...  # type: PySide6.QtGui.QVector4D
        instanceData              = ...  # type: PySide6.QtGui.QVector4D
        row0                      = ...  # type: PySide6.QtGui.QVector4D
        row1                      = ...  # type: PySide6.QtGui.QVector4D
        row2                      = ...  # type: PySide6.QtGui.QVector4D

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, InstanceTableEntry: PySide6.QtQuick3D.QQuick3DInstancing.InstanceTableEntry, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...
        def getColor(self, /) -> PySide6.QtGui.QColor: ...
        def getPosition(self, /) -> PySide6.QtGui.QVector3D: ...
        def getRotation(self, /) -> PySide6.QtGui.QQuaternion: ...
        def getScale(self, /) -> PySide6.QtGui.QVector3D: ...


    def __init__(self, /, parent: PySide6.QtQuick3D.QQuick3DObject | None = ..., *, instanceCountOverride: int | None = ..., hasTransparency: bool | None = ..., depthSortingEnabled: bool | None = ..., shadowBoundsMinimum: PySide6.QtGui.QVector3D | None = ..., shadowBoundsMaximum: PySide6.QtGui.QVector3D | None = ...) -> None: ...

    @staticmethod
    def calculateTableEntry(position: PySide6.QtGui.QVector3D, scale: PySide6.QtGui.QVector3D, eulerRotation: PySide6.QtGui.QVector3D, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /, customData: PySide6.QtGui.QVector4D = ...) -> PySide6.QtQuick3D.QQuick3DInstancing.InstanceTableEntry: ...
    @staticmethod
    def calculateTableEntryFromQuaternion(position: PySide6.QtGui.QVector3D, scale: PySide6.QtGui.QVector3D, rotation: PySide6.QtGui.QQuaternion, color: PySide6.QtGui.QColor | str | PySide6.QtGui.QRgba64 | typing.Any | PySide6.QtCore.Qt.GlobalColor | int, /, customData: PySide6.QtGui.QVector4D = ...) -> PySide6.QtQuick3D.QQuick3DInstancing.InstanceTableEntry: ...
    def depthSortingEnabled(self, /) -> bool: ...
    def getInstanceBuffer(self, /) -> typing.Tuple[bool, str]: ...
    def hasTransparency(self, /) -> bool: ...
    def instanceBuffer(self, /) -> typing.Tuple[PySide6.QtCore.QByteArray, int]: ...
    def instanceColor(self, index: int, /) -> PySide6.QtGui.QColor: ...
    def instanceCountOverride(self, /) -> int: ...
    def instanceCustomData(self, index: int, /) -> PySide6.QtGui.QVector4D: ...
    def instancePosition(self, index: int, /) -> PySide6.QtGui.QVector3D: ...
    def instanceRotation(self, index: int, /) -> PySide6.QtGui.QQuaternion: ...
    def instanceScale(self, index: int, /) -> PySide6.QtGui.QVector3D: ...
    def markDirty(self, /) -> None: ...
    def setDepthSortingEnabled(self, enabled: bool, /) -> None: ...
    def setHasTransparency(self, hasTransparency: bool, /) -> None: ...
    def setInstanceCountOverride(self, instanceCountOverride: int, /) -> None: ...
    def setShadowBoundsMaximum(self, newShadowBoundsMinimum: PySide6.QtGui.QVector3D, /) -> None: ...
    def setShadowBoundsMinimum(self, newShadowBoundsMinimum: PySide6.QtGui.QVector3D, /) -> None: ...
    def shadowBoundsMaximum(self, /) -> PySide6.QtGui.QVector3D: ...
    def shadowBoundsMinimum(self, /) -> PySide6.QtGui.QVector3D: ...


class QQuick3DObject(PySide6.QtCore.QObject, PySide6.QtQml.QQmlParserStatus):

    childrenChanged          : typing.ClassVar[Signal] = ... # childrenChanged()
    parentChanged            : typing.ClassVar[Signal] = ... # parentChanged()
    stateChanged             : typing.ClassVar[Signal] = ... # stateChanged()

    class ItemChange(enum.Enum):

        ItemChildAddedChange      = 0x0
        ItemChildRemovedChange    = 0x1
        ItemSceneChange           = 0x2
        ItemVisibleHasChanged     = 0x3
        ItemParentHasChanged      = 0x4
        ItemOpacityHasChanged     = 0x5
        ItemActiveFocusHasChanged = 0x6
        ItemRotationHasChanged    = 0x7
        ItemAntialiasingHasChanged = 0x8
        ItemDevicePixelRatioHasChanged = 0x9
        ItemEnabledHasChanged     = 0xa


    def childItems(self, /) -> typing.List[PySide6.QtQuick3D.QQuick3DObject]: ...
    def classBegin(self, /) -> None: ...
    def componentComplete(self, /) -> None: ...
    def isComponentComplete(self, /) -> bool: ...
    def markAllDirty(self, /) -> None: ...
    def parentItem(self, /) -> PySide6.QtQuick3D.QQuick3DObject: ...
    def preSync(self, /) -> None: ...
    def setParentItem(self, parentItem: PySide6.QtQuick3D.QQuick3DObject, /) -> None: ...
    def setState(self, state: str, /) -> None: ...
    def state(self, /) -> str: ...
    def update(self, /) -> None: ...


class QQuick3DRenderExtension(PySide6.QtQuick3D.QQuick3DObject):

    def __init__(self, /, parent: PySide6.QtQuick3D.QQuick3DObject | None = ...) -> None: ...


class QQuick3DTextureData(PySide6.QtQuick3D.QQuick3DObject):

    textureDataNodeDirty     : typing.ClassVar[Signal] = ... # textureDataNodeDirty()

    class Format(enum.Enum):

        None_                     = 0x0
        RGBA8                     = 0x1
        RGBA16F                   = 0x2
        RGBA32F                   = 0x3
        RGBE8                     = 0x4
        R8                        = 0x5
        R16                       = 0x6
        R16F                      = 0x7
        R32F                      = 0x8
        BC1                       = 0x9
        BC2                       = 0xa
        BC3                       = 0xb
        BC4                       = 0xc
        BC5                       = 0xd
        BC6H                      = 0xe
        BC7                       = 0xf
        DXT1_RGBA                 = 0x10
        DXT1_RGB                  = 0x11
        DXT3_RGBA                 = 0x12
        DXT5_RGBA                 = 0x13
        ETC2_RGB8                 = 0x14
        ETC2_RGB8A1               = 0x15
        ETC2_RGBA8                = 0x16
        ASTC_4x4                  = 0x17
        ASTC_5x4                  = 0x18
        ASTC_5x5                  = 0x19
        ASTC_6x5                  = 0x1a
        ASTC_6x6                  = 0x1b
        ASTC_8x5                  = 0x1c
        ASTC_8x6                  = 0x1d
        ASTC_8x8                  = 0x1e
        ASTC_10x5                 = 0x1f
        ASTC_10x6                 = 0x20
        ASTC_10x8                 = 0x21
        ASTC_10x10                = 0x22
        ASTC_12x10                = 0x23
        ASTC_12x12                = 0x24


    def __init__(self, /, parent: PySide6.QtQuick3D.QQuick3DObject | None = ...) -> None: ...

    def depth(self, /) -> int: ...
    def format(self, /) -> PySide6.QtQuick3D.QQuick3DTextureData.Format: ...
    def hasTransparency(self, /) -> bool: ...
    def markAllDirty(self, /) -> None: ...
    def setDepth(self, depth: int, /) -> None: ...
    def setFormat(self, format: PySide6.QtQuick3D.QQuick3DTextureData.Format, /) -> None: ...
    def setHasTransparency(self, hasTransparency: bool, /) -> None: ...
    def setSize(self, size: PySide6.QtCore.QSize, /) -> None: ...
    def setTextureData(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> None: ...
    def size(self, /) -> PySide6.QtCore.QSize: ...
    def textureData(self, /) -> PySide6.QtCore.QByteArray: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof
